EastmoneyRank = {
    "f12": "代码",
    "f14": "名称",
    "f3": "涨跌幅",
    "f15": "最新价",
    "f4": "涨跌额",
    "f5": "成交量",
    "f6": "成交额",
    "f18": "昨日收盘",
}

EastmoneyHeaders = {
    "Host": "19.push2.eastmoney.com",
    "User-Agent": "Mozilla/5.0 (Windows NT 6.3; WOW64; Trident/7.0; Touch; rv:11.0) like Gecko",
    "Accept": "*/*",
    "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
    "Referer": "http://quote.eastmoney.com/center/gridlist.html",
}
EastmoneyFundHeaders = {
    "User-Agent": "EMProjJijin/6.2.8 (iPhone; iOS 13.6; Scale/2.00)",
    "GTOKEN": "98B423068C1F4DEF9842F82ADF08C5db",
    "clientInfo": "ttjj-iPhone10,1-iOS-iOS13.6",
    "Content-Type": "application/x-www-form-urlencoded",
    "Host": "fundmobapi.eastmoney.com",
    "Referer": "https://mpservice.com/516939c37bdb4ba2b1138c50cf69a2e1/release/pages/FundHistoryNetWorth",
}
